@@ -26,7 +26,7 @@ import qualified Data.Map as Map
 import Data.Time (LocalTime, Day)
 import Language.Haskell.TH (TypeQ)
 
-import Database.Relational.Query
+import Database.Relational
   (Query, relationalQuery, Relation, query, relation',
    wheres, (.=.), (!), (><), placeholder, asc, value)
 
