@@ -18,7 +18,7 @@ import           Data.ByteString        (ByteString)
 import           Control.Applicative    ((<|>))
 import           Language.Haskell.TH    (TypeQ)
 
-import Database.Relational.Query        ( Query
+import Database.Relational              ( Query
                                         , relationalQuery
                                         , query
                                         , relation'
