@@ -34,7 +34,7 @@ import Data.Time
   (DiffTime, NominalDiffTime,
    LocalTime, ZonedTime, Day, TimeOfDay)
 
-import Database.Relational.Query
+import Database.Relational
   (Query, relationalQuery, Relation, query, query', relation', relation, union,
    wheres, (.=.), (.>.), in', values, (!), fst', snd',
    placeholder, asc, value, unsafeProjectSql, (><))
